==> zio-aws-pinpoint_3-5.17.104.12-sources.jar: zio/aws/pinpoint/model/MultiConditionalBranch.scala <==
package zio.aws.pinpoint.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.pinpoint.model.primitives.__string
import scala.jdk.CollectionConverters.*
final case class MultiConditionalBranch(
    condition: Option[zio.aws.pinpoint.model.SimpleCondition] = None,
    nextActivity: Option[__string] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.pinpoint.model.MultiConditionalBranch = {
    import MultiConditionalBranch.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.pinpoint.model.MultiConditionalBranch
      .builder()
      .optionallyWith(condition.map(value => value.buildAwsValue()))(
        _.condition
      )
      .optionallyWith(
        nextActivity.map(value => __string.unwrap(value): java.lang.String)
      )(_.nextActivity)
      .build()
  }
  def asReadOnly: zio.aws.pinpoint.model.MultiConditionalBranch.ReadOnly =
    zio.aws.pinpoint.model.MultiConditionalBranch.wrap(buildAwsValue())
}
object MultiConditionalBranch {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.pinpoint.model.MultiConditionalBranch
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.pinpoint.model.MultiConditionalBranch =
      zio.aws.pinpoint.model.MultiConditionalBranch(
        condition.map(value => value.asEditable),
        nextActivity.map(value => value)
      )
    def condition: Option[zio.aws.pinpoint.model.SimpleCondition.ReadOnly]
    def nextActivity: Option[__string]
    def getCondition
        : ZIO[Any, AwsError, zio.aws.pinpoint.model.SimpleCondition.ReadOnly] =
      AwsError.unwrapOptionField("condition", condition)
    def getNextActivity: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("nextActivity", nextActivity)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.pinpoint.model.MultiConditionalBranch
  ) extends zio.aws.pinpoint.model.MultiConditionalBranch.ReadOnly {
    override val condition
        : Option[zio.aws.pinpoint.model.SimpleCondition.ReadOnly] = scala
      .Option(impl.condition())
      .map(value => zio.aws.pinpoint.model.SimpleCondition.wrap(value))
    override val nextActivity: Option[__string] = scala
      .Option(impl.nextActivity())
      .map(value => zio.aws.pinpoint.model.primitives.__string(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.pinpoint.model.MultiConditionalBranch
  ): zio.aws.pinpoint.model.MultiConditionalBranch.ReadOnly = new Wrapper(impl)
}

==> zio-aws-pinpoint_3-5.17.267.1-sources.jar: zio/aws/pinpoint/model/MultiConditionalBranch.scala <==
package zio.aws.pinpoint.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.pinpoint.model.primitives.__string
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class MultiConditionalBranch(
    condition: Optional[zio.aws.pinpoint.model.SimpleCondition] =
      Optional.Absent,
    nextActivity: Optional[__string] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.pinpoint.model.MultiConditionalBranch = {
    import MultiConditionalBranch.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.pinpoint.model.MultiConditionalBranch
      .builder()
      .optionallyWith(condition.map(value => value.buildAwsValue()))(
        _.condition
      )
      .optionallyWith(nextActivity.map(value => value: java.lang.String))(
        _.nextActivity
      )
      .build()
  }
  def asReadOnly: zio.aws.pinpoint.model.MultiConditionalBranch.ReadOnly =
    zio.aws.pinpoint.model.MultiConditionalBranch.wrap(buildAwsValue())
}
object MultiConditionalBranch {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.pinpoint.model.MultiConditionalBranch
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.pinpoint.model.MultiConditionalBranch =
      zio.aws.pinpoint.model.MultiConditionalBranch(
        condition.map(value => value.asEditable),
        nextActivity.map(value => value)
      )
    def condition: Optional[zio.aws.pinpoint.model.SimpleCondition.ReadOnly]
    def nextActivity: Optional[__string]
    def getCondition
        : ZIO[Any, AwsError, zio.aws.pinpoint.model.SimpleCondition.ReadOnly] =
      AwsError.unwrapOptionField("condition", condition)
    def getNextActivity: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("nextActivity", nextActivity)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.pinpoint.model.MultiConditionalBranch
  ) extends zio.aws.pinpoint.model.MultiConditionalBranch.ReadOnly {
    override val condition
        : Optional[zio.aws.pinpoint.model.SimpleCondition.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.condition())
        .map(value => zio.aws.pinpoint.model.SimpleCondition.wrap(value))
    override val nextActivity: Optional[__string] = zio.aws.core.internal
      .optionalFromNullable(impl.nextActivity())
      .map(value => value: __string)
  }
  def wrap(
      impl: software.amazon.awssdk.services.pinpoint.model.MultiConditionalBranch
  ): zio.aws.pinpoint.model.MultiConditionalBranch.ReadOnly = new Wrapper(impl)
}
